# Tikos Reasoning Platform

Tikos Reasoning Platform harnesses the power of empirically established 2nd-generation AI and statistical toolsets to offer its users advanced 3rd-generation AI capabilities.

## How to access the platform

To get Alpha API keys, please register your request via https://tikos.tech/

## Licence

Apache-2.0

## Release Notes

1. v 0.0.7, added 

   i. GetGraphStructure: Automatically extract graph Vertexes and Edges that can be further refined by the user

   ii. GenerateGraph: Provide Tikos Reasoning Platform the refined graph Vertexes and Edges to build the standard knowledge graph

   iii. GetGraph: Get the whole graph for an extraction request

   iv. GetGraphRelationships: Get relationships between two Vertexes

2. v 0.0.8, added

   i. GetGraphRetrieval: Retrieve query response along with the Graph relationships for the requested retrieve query

3. v 0.0.9, added

   i. GetGraphRetrievalWithDS: Retrieve query response along with the Graph relationships for the requested retrieve query with Graph Node data sets as JSON